--[[ 
  -- 
  -- DB Var: AutoRollerDB
  -- Slash commands:
  -- 	/autoroller - print current state [ enabled, disabled, BoE [pass | need | greed | nothing], BoP [...], recipe [..] ]
  -- 	/autoroller toggle = enable | disable
  -- 	/autoroller [boe | bop | recipe] [pass | need | greed | nothing] - set 
  -- 
--]]

---------------   locals   ---------------

local _G = _G
local chatFrame = _G.DEFAULT_CHAT_FRAME
local GetLootRollItemInfo = _G.GetLootRollItemInfo
local GetLootRollItemLink = _G.GetLootRollItemLink
local GetItemInfo = _G.GetItemInfo
local RollOnLoot = _G.RollOnLoot
local format = _G.string.format
local OpenToCategory = _G.InterfaceOptionsFrame_OpenToCategory

local autoRollerFrame = _G.CreateFrame('Frame');

---------------   initialize db   ---------------

local db

---------------   slash commands   ---------------

local colorize = { 
[false] = "|cffff0000Off|r", 
need = "|cffff0000need|r",
[true] = "|cff00ff00On|r",
greed = "|cffffff00greed|r",
nothing = "|cff00ff00nothing|r",
pass = "|cffffff00pass|r",
}
local setOption = "|cffffff7fAutoRoller: %s|r is now set to |cffffff7f[|r%s|cffffff7f]|r"

local function SlashHandler(cmd)
	cmd = cmd:lower():trim()
	local val
	cmd, val = cmd:match("^(%l+)%s*(%l*)") 
	if cmd == "config" then
		return OpenToCategory("Auto Roller")
	elseif cmd == "toggle" or cmd == "on" or cmd == "off" then
		local val = not db.enabled
		db.enabled = val
		chatFrame:AddMessage(format(setOption, "Toggle", colorize[val]))
		if val then
			return autoRollerFrame:RegisterEvent('START_LOOT_ROLL')
		else
			return autoRollerFrame:UnregisterEvent('START_LOOT_ROLL')
		end
	elseif db[cmd] then
		if val == "pass" or val == "need" or val == "greed" then
			db[cmd] = val
		else
			db[cmd] = "nothing"
		end
		return chatFrame:AddMessage(format(setOption, cmd, colorize[db[cmd]]))
	end
	--fall through, print state msg
	return chatFrame:AddMessage(format([[
|cffffff7fAutoRoller Usage:|r 
/AutoRoller |cff00ffffitemType|r |cffff0000action|r
  |cff00ffffitemType|r - bop, bop, recipe
  |cffff0000action|r - need, greed, pass, nothing
Current Settings:
 - |cffffff7ftoggle: [|r%s|cffffff7f]|r enable/disable addon
 - |cffffff7fboe: [|r%s|cffffff7f]|r rule for BoE items
 - |cffffff7fbop: [|r%s|cffffff7f]|r rule for BoP items
 - |cffffff7frecipe: [|r%s|cffffff7f]|r rule for recipes
]], colorize[db.enabled], colorize[db.boe], colorize[db.bop], colorize[db.recipe]))
end

_G.SLASH_autoRoller1 = "/autoroller";
_G.SlashCmdList.autoRoller = SlashHandler;

---------------   event hanndler   ---------------

autoRollerFrame:SetScript('OnEvent', function(frame, event, arg1)
	if event == 'START_LOOT_ROLL' then
		-- arg1 == rollID
		local _, name, _,_, isBoP = GetLootRollItemInfo(arg1)
		local link = GetLootRollItemLink(arg1)
		local _,_,_,_,_, itemType = GetItemInfo(link) -- cant use name (item must be in inventory)
		
		local roll, val
		
		if itemType == 'Recipe' then
			val = db.recipe
		else
			if isBoP == 1 then
				val = db.bop
			else
				val = db.boe
			end
		end
		
		--RollOnLoot(arg1, {0 : pass, 1 : need, 2 : greed})
		
		if val == "pass" then
			roll = 0
		elseif val == "need" then
			roll = 1
		elseif val == "greed" then
			roll = 2
		else
			return
		end
		
		chatFrame:AddMessage(format("|cff00AA00AutoRoller: rolling|r %s |cff00AA00on|r %s", val, link))
		
		return RollOnLoot(arg1, roll)
	elseif event == 'ADDON_LOADED' and arg1 == "AutoRoller" then

		db = _G.AutoRollerDB 
		if not db then
			db = {
				enabled = true,
				boe = "greed",
				bop = "pass",
				recipe = "nothing",
			}
			_G.AutoRollerDB = db
		end
		
		if db.enabled then
			return frame:RegisterEvent('START_LOOT_ROLL')
--		else
--			return frame:UnregisterEvent('START_LOOT_ROLL') -- necessary?
		end
	end
end);
autoRollerFrame:RegisterEvent('ADDON_LOADED');